==> selenium-selenium-4.38.0.gh.tar.gz: selenium-selenium-4.38.0/dotnet/src/webdriver/BiDi/Storage/SetCookieCommand.cs <==
// <copyright file="SetCookieCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Communication;
using OpenQA.Selenium.BiDi.Communication.Json.Converters;
using System;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.Storage;

internal sealed class SetCookieCommand(SetCookieParameters @params)
    : Command<SetCookieParameters, SetCookieResult>(@params, "storage.setCookie");

internal sealed record SetCookieParameters(PartialCookie Cookie, PartitionDescriptor? Partition) : Parameters;

public sealed record PartialCookie(string Name, Network.BytesValue Value, string Domain)
{
    public string? Path { get; set; }

    public bool? HttpOnly { get; set; }

    public bool? Secure { get; set; }

    public Network.SameSite? SameSite { get; set; }

    [JsonConverter(typeof(DateTimeOffsetSecondsConverter))]
    public DateTimeOffset? Expiry { get; set; }
}

public sealed class SetCookieOptions : CommandOptions
{
    public PartitionDescriptor? Partition { get; set; }
}

public sealed record SetCookieResult(PartitionKey PartitionKey) : EmptyResult;

==> selenium-selenium-4.39.0.gh.tar.gz: selenium-selenium-4.39.0/dotnet/src/webdriver/BiDi/Storage/SetCookieCommand.cs <==
// <copyright file="SetCookieCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Json.Converters;
using System;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.Storage;

internal sealed class SetCookieCommand(SetCookieParameters @params)
    : Command<SetCookieParameters, SetCookieResult>(@params, "storage.setCookie");

internal sealed record SetCookieParameters(PartialCookie Cookie, PartitionDescriptor? Partition) : Parameters;

public sealed record PartialCookie(string Name, Network.BytesValue Value, string Domain)
{
    public string? Path { get; set; }

    public bool? HttpOnly { get; set; }

    public bool? Secure { get; set; }

    public Network.SameSite? SameSite { get; set; }

    [JsonConverter(typeof(DateTimeOffsetSecondsConverter))]
    public DateTimeOffset? Expiry { get; set; }
}

public sealed class SetCookieOptions : CommandOptions
{
    public PartitionDescriptor? Partition { get; set; }
}

public sealed record SetCookieResult(PartitionKey PartitionKey) : EmptyResult;
